Skip to contents

Plot model-based reliability evidence

Usage

# S3 method for class 'nomo_reliability'
plot(x, ...)

Arguments

x

A nomo_reliability object.

...

Unused.

Value

A ggplot2 object. The conceptual 0-to-1 reliability range is shown by default and expands only if an estimate or interval lies outside it.